@@ -29,13 +29,17 @@ OF_SUBCLASSING_RESTRICTED
 	OHGameControllerAxis *_axis;
 }
 
-@property (readonly, nonatomic) OHGameControllerAxis *axis;
+@property (readonly, nonatomic) OHGameControllerAxis *oh_axis;
 
-- (instancetype)initWithName: (OFString *)name
-		      analog: (bool)analog OF_UNAVAILABLE;
-- (instancetype)initWithName: (OFString *)name
-			axis: (OHGameControllerAxis *)axis
-    OF_DESIGNATED_INITIALIZER;
++ (instancetype)oh_buttonWithName: (OFString *)name
+			   analog: (bool)analog OF_UNAVAILABLE;
++ (instancetype)oh_buttonWithName: (OFString *)name
+			     axis: (OHGameControllerAxis *)axis;
+- (instancetype)oh_initWithName: (OFString *)name
+			 analog: (bool)analog OF_UNAVAILABLE;
+- (instancetype)oh_initWithName: (OFString *)name
+			   axis: (OHGameControllerAxis *)axis
+    OF_METHOD_FAMILY(init);
 @end
 
 OF_ASSUME_NONNULL_END
