@@ -25,16 +25,19 @@ OF_ASSUME_NONNULL_BEGIN
 @interface OHEvdevGameControllerProfile: OFObject <OHGameControllerProfile,
     OHEvdevMapping>
 {
-	OFDictionary OF_GENERIC(OFString *, OHGameControllerButton *) *_buttons;
+	OFDictionary OF_GENERIC(OFString *, OF_KINDOF(OHGameControllerButton *))
+	    *_buttons;
 	OFDictionary OF_GENERIC(OFString *, OHGameControllerAxis *) *_axes;
 	uint16_t _vendorID, _productID;
 }
 
-- (instancetype)initWithKeyBits: (unsigned long *)keyBits
-			 evBits: (unsigned long *)evBits
-			absBits: (unsigned long *)absBits
-		       vendorID: (uint16_t)vendorID
-		      productID: (uint16_t)productID;
+- (instancetype)init OF_UNAVAILABLE;
+
+- (instancetype)oh_initWithKeyBits: (unsigned long *)keyBits
+			    evBits: (unsigned long *)evBits
+			   absBits: (unsigned long *)absBits
+			  vendorID: (uint16_t)vendorID
+			 productID: (uint16_t)productID OF_METHOD_FAMILY(init);
 @end
 
 OF_ASSUME_NONNULL_END
